@@ -6,7 +6,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! sql-builder = "0.7"
+//! sql-builder = "0.8"
 //! ```
 //!
 //! Next, add this to your crate:
@@ -734,6 +734,36 @@ impl SqlBuilder {
         self
     }
 
+    /// Add SET part with escaped string value (for UPDATE).
+    ///
+    /// ```
+    /// extern crate sql_builder;
+    ///
+    /// # use std::error::Error;
+    /// use sql_builder::SqlBuilder;
+    ///
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// let sql = SqlBuilder::update_table("books")
+    ///     .set_str("comment", "Don't distribute!")
+    ///     .and_where_le("price", "100")
+    ///     .sql()?;
+    ///
+    /// assert_eq!("UPDATE books SET comment = 'Don''t distribute!' WHERE price <= 100;", &sql);
+    /// // add                       ^^^^^^^    ^^^^^^^^^^^^^^^^^^
+    /// // here                       field           value
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn set_str<S, T>(&mut self, field: S, value: T) -> &mut Self
+    where
+        S: ToString,
+        T: ToString,
+    {
+        let expr = format!("{} = '{}'", &field.to_string(), &esc(&value.to_string()));
+        self.sets.push(expr);
+        self
+    }
+
     /// Add VALUES part (for INSERT).
     ///
     /// ```
@@ -1592,13 +1622,13 @@ impl SqlBuilder {
     /// let sql = SqlBuilder::select_from("books")
     ///     .field("title")
     ///     .field("price")
-    ///     .or_where_lt("price", 100.to_string())
+    ///     .or_where_le("price", 100.to_string())
     ///     .or_where_le("price", 300.to_string())
     ///     .sql()?;
     ///
-    /// assert_eq!("SELECT title, price FROM books WHERE price < 100 OR price <= 300;", &sql);
-    /// // add                                           ^^^^^   ^^^    ^^^^^    ^^^
-    /// // here                                          field  value   field   value
+    /// assert_eq!("SELECT title, price FROM books WHERE price <= 100 OR price <= 300;", &sql);
+    /// // add                                           ^^^^^    ^^^    ^^^^^    ^^^
+    /// // here                                          field   value   field   value
     /// # Ok(())
     /// # }
     /// ```
@@ -1662,8 +1692,8 @@ impl SqlBuilder {
     ///     .sql()?;
     ///
     /// assert_eq!("SELECT price FROM books WHERE title LIKE '%Alice''s' OR title LIKE '%Philosopher''s';", &sql);
-    /// // add                                    ^^^^^      ^^^^^^^^^^^    ^^^^^      ^^^^^^^^^^^^^^^^^
-    /// // here                                   field         mask        field            mask
+    /// // add                                    ^^^^^        ^^^^^^^^     ^^^^^        ^^^^^^^^^^^^^^
+    /// // here                                   field          mask       field             mask
     /// # Ok(())
     /// # }
     /// ```
@@ -1695,7 +1725,7 @@ impl SqlBuilder {
     ///     .sql()?;
     ///
     /// assert_eq!("SELECT price FROM books WHERE title LIKE 'Alice''s%' OR title LIKE 'Philosopher''s%';", &sql);
-    /// // add                                    ^^^^^      ^^^^^^^^^^^    ^^^^^      ^^^^^^^^^^^^^^^^^
+    /// // add                                    ^^^^^       ^^^^^^^^      ^^^^^       ^^^^^^^^^^^^^^  
     /// // here                                   field         mask        field            mask
     /// # Ok(())
     /// # }
@@ -1794,8 +1824,8 @@ impl SqlBuilder {
     ///     .sql()?;
     ///
     /// assert_eq!("SELECT price FROM books WHERE title NOT LIKE '%Alice''s' OR title NOT LIKE '%Philosopher''s';", &sql);
-    /// // add                                    ^^^^^          ^^^^^^^^^^^    ^^^^^          ^^^^^^^^^^^^^^^^^
-    /// // here                                   field             mask        field                mask
+    /// // add                                    ^^^^^            ^^^^^^^^     ^^^^^            ^^^^^^^^^^^^^^
+    /// // here                                   field              mask       field                 mask
     /// # Ok(())
     /// # }
     /// ```
@@ -1827,7 +1857,7 @@ impl SqlBuilder {
     ///     .sql()?;
     ///
     /// assert_eq!("SELECT price FROM books WHERE title NOT LIKE 'Alice''s%' OR title NOT LIKE 'Philosopher''s%';", &sql);
-    /// // add                                    ^^^^^          ^^^^^^^^^^^    ^^^^^          ^^^^^^^^^^^^^^^^^
+    /// // add                                    ^^^^^           ^^^^^^^^      ^^^^^           ^^^^^^^^^^^^^^  
     /// // here                                   field             mask        field                mask
     /// # Ok(())
     /// # }
@@ -2970,6 +3000,21 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_mark_as_not_distr() -> Result<(), Box<dyn Error>> {
+        let sql = SqlBuilder::update_table("books")
+            .set_str("comment", "Don't distribute!")
+            .and_where_le("price", "100")
+            .sql()?;
+
+        assert_eq!(
+            "UPDATE books SET comment = 'Don''t distribute!' WHERE price <= 100;",
+            &sql
+        );
+
+        Ok(())
+    }
+
     #[test]
     fn test_remove_all_expensive_books() -> Result<(), Box<dyn Error>> {
         let sql = SqlBuilder::delete_from("books")
